functions {
  real f(real b0, real bs, int Y,
         real scf, real rnf, real sis2_3, real stg,
          int SCF, int RNF, int SIS2_3, int Stage_N,
         real x){
    real q;
    q = inv_logit(x + scf*SCF + rnf*RNF + 
                      sis2_3*SIS2_3 + stg*Stage_N);
    return(
      normal_lpdf(x | b0, bs) + bernoulli_lpmf(Y | q)
    );
  }
      
  real log_lik_Simpson(real b0, real bs, int Y, 
                       real scf, real rnf, real sis2_3,
                       real stg,
                       int SCF, int RNF, int SIS2_3,
                       int Stage_N,
                       real a, real b, int M){ 
    vector[M+1] lp;
    real h;
    h = (b-a)/M;
    lp[1] = f(b0, bs, Y, scf, rnf, sis2_3, stg, SCF, RNF, SIS2_3, Stage_N, a);
    for (m in 1:(M/2))
      lp[2*m] = log(4) + f(b0, bs, Y, scf, rnf, sis2_3, stg, SCF, RNF, SIS2_3, Stage_N, a+h*(2*m-1));
    for (m in 1:(M/2-1))
      lp[2*m+1] = log(2) + f(b0, bs, Y, scf, rnf, sis2_3, stg, SCF, RNF, SIS2_3, Stage_N, a+h*2*m);
    lp[M+1] = f(b0, bs, Y, scf, rnf, sis2_3, stg, SCF, RNF, SIS2_3, Stage_N, b);
    return(log(h/3) + log_sum_exp(lp));
  }
}

data {
  int N;
  int Micronuc[N];
  int Lineage_ID[N];
  int LN;
  int SCF[N];
  int RNF[N];
  int SIS2_3[N];
  int Stage_N[N];
}

parameters {
  real b0;
  real<lower=0> bs;
  vector[LN] b;
  // vector[LN] bw;
  real scf;
  real rnf;
  real sis2_3;
  real stg;
}

transformed parameters {
  real q[N];
  // vector[LN] b;
  
  // b = b0 + bs*bw;
  
  for (n in 1:N)
    q[n] = inv_logit(b[Lineage_ID[n]] + scf*SCF[n] + rnf*RNF[n] + 
                      sis2_3*SIS2_3[n] + 
                      stg*Stage_N[n]);
}

model {
  b ~ normal(b0, bs);
  for (n in 1:N)
    Micronuc[n] ~ bernoulli(q[n]);
}

generated quantities {
  real log_lik[N];
  int pred_Y[N];
  real pb;
  real q_rnf;
  real q_scf2_3;
  real q_sis2_3;
  real q_rnf_stg0;
  real q_scf2_3_stg0;
  real q_ctrl48;
  
  for (n in 1:N){
    log_lik[n] = log_lik_Simpson(b0, bs, Micronuc[n], 
                                 scf, rnf,
                                 sis2_3,
                                 stg,
                                 SIS2_3[n],
                                 SCF[n], RNF[n], 
                                 Stage_N[n],
                                 b0-5*bs, b0+5*bs, 200);
  }
  
  pb = normal_rng(b0, bs);
  q_rnf = inv_logit(pb + rnf + stg);
  q_scf2_3 = inv_logit(pb + scf + sis2_3 + stg);
  q_rnf_stg0 = inv_logit(pb + rnf);
  q_scf2_3_stg0 = inv_logit(pb + scf + sis2_3);
  q_sis2_3 = inv_logit(pb + sis2_3 + stg);
  q_ctrl48 = inv_logit(pb + stg);

}
