functions {
  real f(real b0, real bs, int Y,
         real x){
    real q;
    q = inv_logit(x);
    return(
      normal_lpdf(x | b0, bs) + bernoulli_lpmf(Y | q)
    );
  }
      
  real log_lik_Simpson(real b0, real bs, int Y, 
                       real a, real b, int M){ 
    vector[M+1] lp;
    real h;
    h = (b-a)/M;
    lp[1] = f(b0, bs, Y,  a);
    for (m in 1:(M/2))
      lp[2*m] = log(4) + f(b0, bs, Y,  a+h*(2*m-1));
    for (m in 1:(M/2-1))
      lp[2*m+1] = log(2) + f(b0, bs, Y, a+h*2*m);
    lp[M+1] = f(b0, bs, Y,  b);
    return(log(h/3) + log_sum_exp(lp));
  }
}

data {
  int N;
  int Micronuc[N];
  int Lineage_ID[N];
  int LN;
  int SCF[N];
  int RNF[N];
  int SIS2_3[N];
  int Stage_N[N];
}

parameters {
  real b0;
  real<lower=0> bs;
  vector[LN] b;
}

transformed parameters {
  real q[N];
  
  for (n in 1:N)
    q[n] = inv_logit(b[Lineage_ID[n]]);
}

model {
  b ~ normal(b0, bs);
  for (n in 1:N)
    Micronuc[n] ~ bernoulli(q[n]);
}

generated quantities {
  real log_lik[N];
  int pred_Y[N];
  real pb;
  real q_l;
  
  for (n in 1:N){
    log_lik[n] = log_lik_Simpson(b0, bs, Micronuc[n], 
                                 b0-5*bs, b0+5*bs, 200);
  }
  
  pb = normal_rng(b0, bs);
  q_l = inv_logit(pb);

}
