data {
  int N;
  int LN;
  int ExIDN;
  int ExID[N];
  int Stage_N[N];
  int SCF[N]; //
  int RNF[N]; // Repair/No Fusion
  int SIS2_3[N];

  // int C48[N]; fixed
  int Micronuc[N];
  int<lower=1, upper=LN> Lineage_ID[N];
  real Int_duration[N];
}

parameters {
  real<lower=0> sigma[ExIDN];
  real micro;
  real scf;
  real rnf;
  real sis2_3;

  real stg;
  real b;
}

transformed parameters {
  real mu[N];
  
  for (n in 1:N){
    mu[n] = micro*Micronuc[n] + 
            scf*SCF[n] + 
            rnf*RNF[n] + 
            sis2_3*SIS2_3[n] +
            stg*Stage_N[n] + 
            b;
  }
}

model {
  for (n in 1:N) {
    if (Int_duration[n]<1000){
      target += lognormal_lpdf(Int_duration[n] | mu[n], sigma[ExID[n]]);
    } else {
      target += lognormal_lccdf(Int_duration[n]-1000 | mu[n], sigma[ExID[n]]);
    }
  }
}

generated quantities {
  real log_lik[N];

  real pInt_1_0;
  real pInt_1_MN;
  
  real pInt_2_0;
  real pInt_2_MN;
  
  real pInt_3_0;
  real pInt_3_MN;
  
  real pInt_4_0;
  real pInt_4_MN;  
  
  real pInt_5_0;
  real pInt_5_MN;
  
  real pInt_6_0;
  real pInt_6_MN;
  

  
  // no fusion
  pInt_1_0 = lognormal_rng(b + sis2_3 + stg, sigma[4]); // sis2_3_mCit Stage_N
  pInt_1_MN = lognormal_rng(micro + sis2_3 + stg + b, sigma[4]); // 
  
  pInt_2_0 = lognormal_rng(b + rnf, sigma[2]); // C48 rnf
  pInt_2_MN = lognormal_rng(micro + rnf + b, sigma[2]); //  
  
  pInt_3_0 = lognormal_rng(b + rnf + stg, sigma[3]); // C48 rnf Stage_N
  pInt_3_MN = lognormal_rng(micro + rnf + stg + b, sigma[3]); //  
  
  pInt_4_0 = lognormal_rng(b + stg, sigma[1]); // C48_mCit Stage_N
  pInt_4_MN = lognormal_rng(micro + stg + b, sigma[1]); // 
  
  
  // fusion - scf 
  pInt_5_0 = lognormal_rng(scf + sis2_3 + b, sigma[5]); // sis2_3_Fusion
  pInt_5_MN = lognormal_rng(micro + sis2_3 + scf + b, sigma[5]); //
  
  pInt_6_0 = lognormal_rng(scf + sis2_3 + stg + b, sigma[6]); // sis2_3_Fusion Stage_N
  pInt_6_MN = lognormal_rng(micro + sis2_3 + scf + stg + b, sigma[6]); // 
  


  for (n in 1:N) {
    if (Int_duration[n]<1000){
      log_lik[n] = lognormal_lpdf(Int_duration[n] | mu[n], sigma[ExID[n]]);
    } else {
      log_lik[n] = lognormal_lccdf(Int_duration[n]-1000 | mu[n], sigma[ExID[n]]);
    }
  }
}

