functions {
  real f(real Int_duration,
         real scf, real rnf, real sis2_3, real stg,
         int SCF, int  RNF, int  SIS2_3,  int  Stage_N,         
         real sigma,
         real b0, real bs,
         real x){
    real lp;
    real mu;
    mu = x + scf*SCF + rnf*RNF + sis2_3*SIS2_3 +  stg*Stage_N;
    if (Int_duration < 1000) {
      lp = normal_lpdf(x | b0, bs) + lognormal_lpdf(Int_duration | mu, sigma);
    } else {
      lp = normal_lpdf(x | b0, bs) + lognormal_lccdf(Int_duration-1000 | mu, sigma);
    }
    return(lp);
  }

  real log_lik_Simpson(real Int_duration,
                       real scf, real rnf, real sis2_3, real stg,
                       int SCF, int  RNF, int  SIS2_3, int  Stage_N,
                       real sigma,
                       real b0,
                       real bs,
                       real a, real b, int M){
    vector[M+1] lp;
    real h;
    h = (b-a)/M;
    lp[1] = f(Int_duration, 
              scf, rnf, sis2_3, stg, 
              SCF, RNF, SIS2_3, Stage_N,
                          sigma, b0, bs,    a);
    for (m in 1:(M/2))
      lp[2*m] = log(4) + f(Int_duration, 
                           scf, rnf, sis2_3,  stg, 
                           SCF, RNF, SIS2_3,  Stage_N,
                                  sigma, b0, bs,    a+h*(2*m-1));
    for (m in 1:(M/2-1))
      lp[2*m+1] = log(2) + f(Int_duration, 
                            scf, rnf, sis2_3,  stg, 
                            SCF, RNF, SIS2_3,  Stage_N,
                              sigma, b0, bs,    a+h*2*m);
    lp[M+1] = f(Int_duration, 
                scf, rnf, sis2_3,  stg, 
                SCF, RNF, SIS2_3,  Stage_N,sigma, b0, bs,    b);
    return(log(h/3) + log_sum_exp(lp));
  }
}

data {
  int N;
  int LN;
  int ExIDN;
  int ExID[N];
  int Stage_N[N];
  int SCF[N]; //
  int RNF[N]; // Repair/No Fusion
  int SIS2_3[N];
  // int C48[N]; fixed
  int Micronuc[N];
  int<lower=1, upper=LN> Lineage_ID[N];
  real Int_duration[N];
}

parameters {
  real<lower=0> sigma[ExIDN];
  real scf;
  real rnf;
  real sis2_3;
  real stg;
  vector[LN] b;
  real b0;
  real<lower=0> bs;
}

transformed parameters {
  real mu[N];
  
  for (n in 1:N){
    mu[n] = scf*SCF[n] + 
            rnf*RNF[n] + 
            sis2_3*SIS2_3[n] + 
            stg*Stage_N[n] + 
            b[Lineage_ID[n]];
  }
}

model {
  b ~ normal(b0, bs);
  for (n in 1:N) {
    if (Int_duration[n]<1000){
      target += lognormal_lpdf(Int_duration[n] | mu[n], sigma[ExID[n]]);
    } else {
      target += lognormal_lccdf(Int_duration[n]-1000 | mu[n], sigma[ExID[n]]);
    }
  }
}

generated quantities {
  real log_lik[N];
  real pred_Y[N];

  for (n in 1:N) {
    log_lik[n] = log_lik_Simpson(Int_duration[n],
                                 scf,  rnf,  sis2_3,   stg,
                                 SCF[n],  RNF[n],  SIS2_3[n],  Stage_N[n],
                                 sigma[ExID[n]],
                                 b0, bs,
                                 b0-5*bs, b0+5*bs, 100);
    pred_Y[n] = lognormal_rng(mu[n], sigma[ExID[n]]);
  }
}

