data {
  int N;
  int LN;
  int ExIDN;
  int ExID[N];
  int Stage_N[N];
  int SCF[N]; //
  int RNF[N]; // Repair/No Fusion
  int SIS2_3[N];

  // int C48[N]; fixed
  int Micronuc[N];
  int<lower=1, upper=LN> Lineage_ID[N];
  real Int_duration[N];
}

parameters {
  real<lower=0> sigma[ExIDN];
  real scf;
  real rnf;
  real sis2_3;

  real stg;
  real b;
}

transformed parameters {
  real mu[N];
  
  for (n in 1:N){
    mu[n] = scf*SCF[n] + 
            rnf*RNF[n] + 
            sis2_3*SIS2_3[n] +
            stg*Stage_N[n] + 
            b;
  }
}

model {
  for (n in 1:N) {
    if (Int_duration[n]<1000){
      target += lognormal_lpdf(Int_duration[n] | mu[n], sigma[ExID[n]]);
    } else {
      target += lognormal_lccdf(Int_duration[n]-1000 | mu[n], sigma[ExID[n]]);
    }
  }
}

generated quantities {
  real log_lik[N];

  for (n in 1:N) {
    if (Int_duration[n]<1000){
      log_lik[n] = lognormal_lpdf(Int_duration[n] | mu[n], sigma[ExID[n]]);
    } else {
      log_lik[n] = lognormal_lccdf(Int_duration[n]-1000 | mu[n], sigma[ExID[n]]);
    }
  }
}

