functions {
  real f(real Int_duration,
         real sigma,
         real b0, real bs,
         real x){
    real lp;
    if (Int_duration < 1000) {
      lp = normal_lpdf(x | b0, bs) + lognormal_lpdf(Int_duration | x, sigma);
    } else {
      lp = normal_lpdf(x | b0, bs) + lognormal_lccdf(Int_duration-1000 | x, sigma);
    }
    return(lp);
  }

  real log_lik_Simpson(real Int_duration,
                       real sigma,
                       real b0,
                       real bs,
                       real a, real b, int M){
    vector[M+1] lp;
    real h;
    h = (b-a)/M;
    lp[1] = f(Int_duration,  sigma, b0, bs,    a);
    for (m in 1:(M/2))
      lp[2*m] = log(4) + f(Int_duration,  sigma, b0, bs,    a+h*(2*m-1));
    for (m in 1:(M/2-1))
      lp[2*m+1] = log(2) + f(Int_duration,  sigma, b0, bs,    a+h*2*m);
    lp[M+1] = f(Int_duration,  sigma, b0, bs,    b);
    return(log(h/3) + log_sum_exp(lp));
  }
}

data {
  int N;
  int LN;
  int ExIDN;
  int ExID[N];
  int Stage_N[N];
  int SCF[N]; //
  int RNF[N]; // Repair/No Fusion
  // int SIS15[N];
  // int SIS36[N];
  // int C48[N]; fixed
  int Micronuc[N];
  int<lower=1, upper=LN> Lineage_ID[N];
  real Int_duration[N];
}

parameters {
  real<lower=0> sigma[ExIDN];
  // real<lower=0> sigma;
  //real micro;
  //real scf;
  // real rnf;
  // real sis15;
  // real sis36;
  // real c48;
  // real stg;
  vector[LN] b;
  real b0;
  real<lower=0> bs;
}

transformed parameters {
  real mu[N];
  
  for (n in 1:N){
    mu[n] = //micro*Micronuc[n] + 
            //scf*SCF[n] + 
            // rnf*RNF[n] + 
            // sis15*SIS15[n] + sis36*SIS36[n] + // c48*C48[n] +
            // stg*Stage_N[n] + 
            b[Lineage_ID[n]];
  }
}

model {
  b ~ normal(b0, bs);
  for (n in 1:N) {
    if (Int_duration[n]<1000){
      target += lognormal_lpdf(Int_duration[n] | mu[n], sigma[ExID[n]]);
    } else {
      target += lognormal_lccdf(Int_duration[n]-1000 | mu[n], sigma[ExID[n]]);
    }
  }
}

generated quantities {
  real log_lik[N];
  real pred_Y[N];

  for (n in 1:N) {
    log_lik[n] = log_lik_Simpson(Int_duration[n],
                                 sigma[ExID[n]],
                                 b0, bs,
                                 b0-5*bs, b0+5*bs, 100);
    pred_Y[n] = lognormal_rng(mu[n], sigma[ExID[n]]);
  }
}

