data {
  int N;
  int LN;
  int ExIDN;
  int ExID[N];
  int Stage_N[N];
  int SCF[N]; //
  int RNF[N]; // Repair/No Fusion
  int SIS2_3[N];
  int Micronuc[N];
  int<lower=1, upper=LN> Lineage_ID[N];
  real Int_duration[N];
}

parameters {
  real micro;
  real scf;
  real rnf;
  real sis2_3;
  real stg;
  real b;
}

transformed parameters {
  real lambda[N];
  for (n in 1:N){
    lambda[n] = micro*Micronuc[n] + 
      scf*SCF[n] + rnf*RNF[n] + sis2_3*SIS2_3[n] + 
      stg*Stage_N[n] + b;
  }
}

model {
  for (n in 1:N) {
    if (Int_duration[n]<1000){
      target += exponential_lpdf(Int_duration[n] | 1/exp(lambda[n]));
    } else {
      target += exponential_lccdf(Int_duration[n]-1000 | 1/exp(lambda[n]));
    }
  }
}

generated quantities {
  real log_lik[N];
  real pred_Y[N];
  
  for (n in 1:N) {
    if (Int_duration[n]<1000) {
      log_lik[n] = exponential_lpdf(Int_duration[n] | 1/exp(lambda[n]));
    } else {
      log_lik[n] = exponential_lccdf(Int_duration[n] | 1/exp(lambda[n]));
    }
    pred_Y[n] = exponential_rng(1/exp(lambda[n]));
  }
}
